index\_calculator.processing
============================

.. currentmodule:: index_calculator

.. autoclass:: processing


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~processing.__init__
      ~processing.processing
